==> igniteui-react-inputs-18.1.3.tgz: package/esm5/lib/XCheckboxBridge.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { XComponentBridge } from "./XComponentBridge";
import { runOn, delegateCombine, delegateRemove, markType } from "igniteui-react-core";
import { NativeUICheckboxChangeEventArgs } from "igniteui-react-core";
/**
 * @hidden
 */
var XCheckboxBridge = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(XCheckboxBridge, _super);
    function XCheckboxBridge(a) {
        var _this = _super.call(this, a) || this;
        _this.d = null;
        _this.e = null;
        return _this;
    }
    XCheckboxBridge.prototype.addHandler = function (a, b, c, d) {
        var e = a;
        switch (c) {
            case 2:
                var f = a;
                e.change = delegateCombine(e.change, runOn(this, this.f));
                this.d = d;
                this.e = b;
                break;
        }
    };
    XCheckboxBridge.prototype.removeHandler = function (a, b, c, d) {
        var e = a;
        switch (c) {
            case 2:
                e.change = delegateRemove(e.change, runOn(this, this.f));
                this.d = null;
                this.e = null;
                break;
        }
    };
    XCheckboxBridge.prototype.f = function (a, b) {
        if (this.d != null) {
            var c = new NativeUICheckboxChangeEventArgs();
            this.d(this.e, c);
        }
    };
    XCheckboxBridge.prototype.getValue = function (a, b) {
        var c = a;
        switch (b) {
            case 4: return c.t;
            case 5: return c.checked;
        }
        return null;
    };
    XCheckboxBridge.prototype.setValue = function (a, b, c) {
        var d = a;
        switch (b) {
            case 4:
                d.t = c;
                return;
            case 5:
                d.checked = c;
                return;
        }
    };
    XCheckboxBridge.$t = markType(XCheckboxBridge, 'XCheckboxBridge', XComponentBridge.$);
    return XCheckboxBridge;
}(XComponentBridge));
export { XCheckboxBridge };

==> igniteui-react-inputs-18.6.1.tgz: package/esm5/lib/XCheckboxBridge.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { XComponentBridge } from "./XComponentBridge";
import { runOn, delegateCombine, delegateRemove, enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { NativeUICheckboxChangeEventArgs } from "igniteui-react-core";
import { BaseControlTheme_$type } from "igniteui-react-core";
/**
 * @hidden
 */
var XCheckboxBridge = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(XCheckboxBridge, _super);
    function XCheckboxBridge(a) {
        var _this = _super.call(this, a) || this;
        _this.u = null;
        _this.v = null;
        return _this;
    }
    XCheckboxBridge.prototype.addHandler = function (a, b, c, d) {
        var e = a;
        switch (c) {
            case 2:
                var f = a;
                e.change = delegateCombine(e.change, runOn(this, this.w));
                this.u = d;
                this.v = b;
                break;
        }
    };
    XCheckboxBridge.prototype.removeHandler = function (a, b, c, d) {
        var e = a;
        switch (c) {
            case 2:
                e.change = delegateRemove(e.change, runOn(this, this.w));
                this.u = null;
                this.v = null;
                break;
        }
    };
    XCheckboxBridge.prototype.w = function (a, b) {
        if (this.u != null) {
            var c = new NativeUICheckboxChangeEventArgs();
            this.u(this.v, c);
        }
    };
    XCheckboxBridge.prototype.getValue = function (a, b) {
        var c = a;
        switch (b) {
            case 4: return c.y;
            case 7: return c.checked;
            case 18: return enumGetBox(BaseControlTheme_$type, c.n);
            case 17: return c.ar;
        }
        return null;
    };
    XCheckboxBridge.prototype.setValue = function (a, b, c) {
        var d = a;
        switch (b) {
            case 4:
                d.y = c;
                return;
            case 7:
                d.checked = c;
                return;
            case 18:
                d.n = EnumUtil.getEnumValue(BaseControlTheme_$type, c);
                break;
            case 17:
                d.ar = c;
                break;
        }
    };
    XCheckboxBridge.$t = markType(XCheckboxBridge, 'XCheckboxBridge', XComponentBridge.$);
    return XCheckboxBridge;
}(XComponentBridge));
export { XCheckboxBridge };
